@@ -2,7 +2,7 @@ package Crypt::PK::ECC;
 
 use strict;
 use warnings;
-our $VERSION = '0.080';
+our $VERSION = '0.087';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 5.57 'import';
 our %EXPORT_TAGS = ( all => [qw( ecc_encrypt ecc_decrypt ecc_sign_message ecc_verify_message ecc_sign_hash ecc_verify_hash ecc_shared_secret )] );
@@ -218,45 +218,37 @@ sub import_key {
   }
   croak "FATAL: invalid key data" unless $data;
 
-  if ($data =~ /-----BEGIN (EC PRIVATE|EC PUBLIC|PUBLIC) KEY-----(.*?)-----END/sg) {
-    $data = pem_to_der($data, $password) or croak "FATAL: PEM/key decode failed";
-    my $rv = eval { $self->_import($data) } || eval { $self->_import_old($data) };
+  if ($data =~ /(-----BEGIN (PUBLIC|EC PRIVATE|PRIVATE|ENCRYPTED PRIVATE) KEY-----(.+?)-----END (PUBLIC|EC PRIVATE|PRIVATE|ENCRYPTED PRIVATE) KEY-----)/s) {
+    my $pem = $1;
+    my $rv = eval { $self->_import_pem($pem, $password) } || eval { $self->_import_old(pem_to_der($pem, $password)) };
     return $rv if $rv;
   }
-  elsif ($data =~ /-----BEGIN PRIVATE KEY-----(.*?)-----END/sg) {
-    $data = pem_to_der($data, $password) or croak "FATAL: PEM/key decode failed";
-    return $self->_import_pkcs8($data, $password);
+  elsif ($data =~ /-----BEGIN CERTIFICATE-----(.+?)-----END CERTIFICATE-----/s) {
+    return $self->_import_pem($data, undef);
   }
-  elsif ($data =~ /-----BEGIN ENCRYPTED PRIVATE KEY-----(.*?)-----END/sg) {
-    $data = pem_to_der($data, $password) or croak "FATAL: PEM/key decode failed";
-    return $self->_import_pkcs8($data, $password);
+  elsif ($data =~ /-----BEGIN OPENSSH PRIVATE KEY-----(.+?)-----END OPENSSH PRIVATE KEY-----/s) {
+    return $self->_import_openssh($data, $password);
   }
-  elsif ($data =~ /^\s*(\{.*?\})\s*$/s) {
-    # JSON Web Key (JWK) - http://tools.ietf.org/html/draft-ietf-jose-json-web-key
-    my $json = "$1";
-    my $h = CryptX::_decode_json($json);
-    if ($h && $h->{kty} eq "EC") {
-      for (qw/x y d/) {
-        $h->{$_} = eval { unpack("H*", decode_b64u($h->{$_})) } if exists $h->{$_};
-      }
-      # names P-192 P-224 P-256 P-384 P-521 are recognized by libtomcrypt
-      return $self->_import_hex($h->{x}, $h->{y}, $h->{d}, $h->{crv});
-    }
-  }
-  elsif ($data =~ /-----BEGIN CERTIFICATE-----(.*?)-----END CERTIFICATE-----/sg) {
-    $data = pem_to_der($data) or croak "FATAL: PEM/cert decode failed";
-    return $self->_import_x509($data);
-  }
-  elsif ($data =~ /---- BEGIN SSH2 PUBLIC KEY ----(.*?)---- END SSH2 PUBLIC KEY ----/sg) {
-    $data = pem_to_der($data) or croak "FATAL: PEM/key decode failed";
-    my ($typ, $skip, $pubkey) = Crypt::PK::_ssh_parse($data);
-    return $self->import_key_raw($pubkey, "$2") if $pubkey && $typ =~ /^ecdsa-(.+?)-(.*)$/;
+  elsif ($data =~ /---- BEGIN SSH2 PUBLIC KEY ----(.+?)---- END SSH2 PUBLIC KEY ----/s) {
+    return $self->_import_openssh($data, undef);
   }
   elsif ($data =~ /(ecdsa-\S+)\s+(\S+)/) {
     $data = decode_b64("$2");
     my ($typ, $skip, $pubkey) = Crypt::PK::_ssh_parse($data);
     return $self->import_key_raw($pubkey, "$2") if $pubkey && $typ =~ /^ecdsa-(.+?)-(.*)$/;
   }
+  elsif ($data =~ /^\s*(\{.*?\})\s*$/s) {
+    # JSON Web Key (JWK) - http://tools.ietf.org/html/draft-ietf-jose-json-web-key
+    my $json = "$1";
+    my $h = CryptX::_decode_json($json) || {};
+    if ($h->{kty} eq "EC") {
+      $h->{x} = eval { unpack("H*", decode_b64u($h->{x})) } if exists $h->{x};
+      $h->{y} = eval { unpack("H*", decode_b64u($h->{y})) } if exists $h->{y};
+      $h->{d} = eval { unpack("H*", decode_b64u($h->{d})) } if exists $h->{d};
+      # names P-192 P-224 P-256 P-384 P-521 are recognized by libtomcrypt
+      return $self->_import_hex($h->{x}, $h->{y}, $h->{d}, $h->{crv});
+    }
+  }
   else {
     my $rv = eval { $self->_import($data) }                  ||
              eval { $self->_import_old($data) }              ||
@@ -861,6 +853,13 @@ to get a fully RFC-7518-compliant signature.
  my $pk = Crypt::PK::ECC->new($priv_key_filename);
  my $signature = $priv->sign_hash($message_hash);
 
+I<Since: CyrptX-0.081>
+
+=head2 sign_hash_eth
+
+Same as L<sign_hash|/sign_hash> only the signature format is as defined by Ethereum.
+32 byte r value, 32 byte s value, 1 recovery byte (27 or 28)
+
 =head2 sign_hash_rfc7518
 
 I<Since: CryptX-0.059>
@@ -875,6 +874,44 @@ Same as L<sign_hash|/sign_hash> only the signature format is as defined by L<htt
 
 =head2 verify_hash_rfc7518
 
+I<Since: CyrptX-0.081>
+
+=head2 verify_hash_eth
+
+Same as L<verify_hash|/verify_hash> only the signature format is as defined by Ethereum.
+Compatible with signatures generated by L<sign_hash_eth|/sign_hash_eth>.
+
+=head2 recovery_pub_eth
+
+Alternative method to verify a signature with recovery of the public key.
+Mainly used for in Ethereum-like blockchain networks.
+This method will recover public key from ECDSA signature in Ethereum format
+(see L<sign_hash_eth|sign_hash_eth>).
+
+ my $pk = Crypt::PK::ECC->new($priv_key_filename);
+ my $signature = $pk->sign_hash_eth($message_hash);
+ my $pub_key = $pk->recovery_pub_eth($sig, $hash)
+
+=head2 recovery_pub
+
+Same logic as recovery_pub_eth except, but compatible with L<sign_hash|/sign_hash>
+signature. The main difference that B<$recid> is required, because B<sign_hash> signature
+doesn't contain parity bit, so you need to specify it explicitly.
+
+ my $pk = Crypt::PK::ECC->new($priv_key_filename);
+ my $signature = $pk->sign_hash($message_hash);
+ my $pub_key = $pk->recovery_pub($signature, $message_hash, $recid)
+
+=head2 recovery_pub_rfc7518
+
+Same logic as recovery_pub_eth except, but compatible with L<sign_hash_refc7518|/sign_hash_refc7518>
+signature. The main difference that B<$recid> is required, because rfc7518 signature
+doesn't contain parity bit, so you need to specify it explicitly.
+
+ my $pk = Crypt::PK::ECC->new($priv_key_filename);
+ my $signature = $pk->sign_hash_rfc7518($message_hash);
+ my $pub_key = $pk->recovery_pub_rfc7518($signature, $message_hash, $recid)
+
 I<Since: CryptX-0.059>
 
 Same as L<verify_hash|/verify_hash> only the signature format is as defined by L<https://tools.ietf.org/html/rfc7518>
