@@ -1,11 +1,5 @@
-/* LibTomCrypt, modular cryptographic library -- Tom St Denis
- *
- * LibTomCrypt is a library that provides various cryptographic
- * algorithms in a highly modular and flexible manner.
- *
- * The library is free for all purposes without any express
- * guarantee it works.
- */
+/* LibTomCrypt, modular cryptographic library -- Tom St Denis */
+/* SPDX-License-Identifier: Unlicense */
 #include "tomcrypt_private.h"
 
 /**
@@ -40,23 +34,19 @@ int radix_to_bin(const void *in, int radix, void *out, unsigned long *len)
    LTC_ARGCHK(in  != NULL);
    LTC_ARGCHK(len != NULL);
 
-   if ((err = mp_init(&mpi)) != CRYPT_OK) return err;
-   if ((err = mp_read_radix(mpi, in, radix)) != CRYPT_OK) goto LBL_ERR;
+   if ((err = ltc_mp_init(&mpi)) != CRYPT_OK) return err;
+   if ((err = ltc_mp_read_radix(mpi, in, radix)) != CRYPT_OK) goto LBL_ERR;
 
-   if ((l = mp_unsigned_bin_size(mpi)) > *len) {
+   if ((l = ltc_mp_unsigned_bin_size(mpi)) > *len) {
       *len = l;
       err = CRYPT_BUFFER_OVERFLOW;
       goto LBL_ERR;
    }
    *len = l;
 
-   if ((err = mp_to_unsigned_bin(mpi, out)) != CRYPT_OK) goto LBL_ERR;
+   if ((err = ltc_mp_to_unsigned_bin(mpi, out)) != CRYPT_OK) goto LBL_ERR;
 
 LBL_ERR:
-   mp_clear(mpi);
+   ltc_mp_clear(mpi);
    return err;
 }
-
-/* ref:         $Format:%D$ */
-/* git commit:  $Format:%H$ */
-/* commit time: $Format:%ai$ */
