@@ -1,11 +1,5 @@
-/* LibTomCrypt, modular cryptographic library -- Tom St Denis
- *
- * LibTomCrypt is a library that provides various cryptographic
- * algorithms in a highly modular and flexible manner.
- *
- * The library is free for all purposes without any express
- * guarantee it works.
- */
+/* LibTomCrypt, modular cryptographic library -- Tom St Denis */
+/* SPDX-License-Identifier: Unlicense */
 
 #include "tomcrypt_private.h"
 
@@ -28,7 +22,7 @@
    @param map      Boolean whether to map back to affine or not (1==map, 0 == leave in projective)
    @return CRYPT_OK on success
 */
-int ltc_ecc_mulmod(void *k, const ecc_point *G, ecc_point *R, void *a, void *modulus, int map)
+int ltc_ecc_mulmod(const void *k, const ecc_point *G, ecc_point *R, const void *a, const void *modulus, int map)
 {
    ecc_point *tG, *M[3];
    int        i, j, err, inf;
@@ -48,16 +42,16 @@ int ltc_ecc_mulmod(void *k, const ecc_point *G, ecc_point *R, void *a, void *mod
    }
 
    /* init montgomery reduction */
-   if ((err = mp_montgomery_setup(modulus, &mp)) != CRYPT_OK)        { goto error; }
-   if ((err = mp_init(&mu)) != CRYPT_OK)                             { goto error; }
-   if ((err = mp_montgomery_normalization(mu, modulus)) != CRYPT_OK) { goto error; }
+   if ((err = ltc_mp_montgomery_setup(modulus, &mp)) != CRYPT_OK)        { goto error; }
+   if ((err = ltc_mp_init(&mu)) != CRYPT_OK)                             { goto error; }
+   if ((err = ltc_mp_montgomery_normalization(mu, modulus)) != CRYPT_OK) { goto error; }
 
    /* for curves with a == -3 keep ma == NULL */
-   if ((err = mp_init(&a_plus3)) != CRYPT_OK)                        { goto error; }
-   if ((err = mp_add_d(a, 3, a_plus3)) != CRYPT_OK)                  { goto error; }
-   if (mp_cmp(a_plus3, modulus) != LTC_MP_EQ) {
-      if ((err = mp_init(&ma)) != CRYPT_OK)                          { goto error; }
-      if ((err = mp_mulmod(a, mu, modulus, ma)) != CRYPT_OK)         { goto error; }
+   if ((err = ltc_mp_init(&a_plus3)) != CRYPT_OK)                        { goto error; }
+   if ((err = ltc_mp_add_d(a, 3, a_plus3)) != CRYPT_OK)                  { goto error; }
+   if (ltc_mp_cmp(a_plus3, modulus) != LTC_MP_EQ) {
+      if ((err = ltc_mp_init(&ma)) != CRYPT_OK)                          { goto error; }
+      if ((err = ltc_mp_mulmod(a, mu, modulus, ma)) != CRYPT_OK)         { goto error; }
    }
 
    /* alloc ram for window temps */
@@ -67,8 +61,8 @@ int ltc_ecc_mulmod(void *k, const ecc_point *G, ecc_point *R, void *a, void *mod
          for (j = 0; j < i; j++) {
              ltc_ecc_del_point(M[j]);
          }
-         mp_clear(mu);
-         mp_montgomery_free(mp);
+         ltc_mp_clear(mu);
+         ltc_mp_montgomery_free(mp);
          return CRYPT_MEM;
       }
    }
@@ -78,10 +72,10 @@ int ltc_ecc_mulmod(void *k, const ecc_point *G, ecc_point *R, void *a, void *mod
    if (tG == NULL)                                                                   { err = CRYPT_MEM; goto done; }
 
    /* tG = G  and convert to montgomery */
-   if ((err = mp_mulmod(G->x, mu, modulus, tG->x)) != CRYPT_OK)                      { goto done; }
-   if ((err = mp_mulmod(G->y, mu, modulus, tG->y)) != CRYPT_OK)                      { goto done; }
-   if ((err = mp_mulmod(G->z, mu, modulus, tG->z)) != CRYPT_OK)                      { goto done; }
-   mp_clear(mu);
+   if ((err = ltc_mp_mulmod(G->x, mu, modulus, tG->x)) != CRYPT_OK)                      { goto done; }
+   if ((err = ltc_mp_mulmod(G->y, mu, modulus, tG->y)) != CRYPT_OK)                      { goto done; }
+   if ((err = ltc_mp_mulmod(G->z, mu, modulus, tG->z)) != CRYPT_OK)                      { goto done; }
+   ltc_mp_clear(mu);
    mu = NULL;
 
    /* calc the M tab */
@@ -94,7 +88,7 @@ int ltc_ecc_mulmod(void *k, const ecc_point *G, ecc_point *R, void *a, void *mod
    mode   = 0;
    bitcnt = 1;
    buf    = 0;
-   digidx = mp_get_digit_count(k) - 1;
+   digidx = ltc_mp_get_digit_count(k) - 1;
 
    /* perform ops */
    for (;;) {
@@ -103,13 +97,13 @@ int ltc_ecc_mulmod(void *k, const ecc_point *G, ecc_point *R, void *a, void *mod
          if (digidx == -1) {
             break;
          }
-         buf    = mp_get_digit(k, digidx);
-         bitcnt = (int) MP_DIGIT_BIT;
+         buf    = ltc_mp_get_digit(k, digidx);
+         bitcnt = (int) LTC_MP_DIGIT_BIT;
          --digidx;
       }
 
       /* grab the next msb from the ltiplicand */
-      i = (int)((buf >> (MP_DIGIT_BIT - 1)) & 1);
+      i = (int)((buf >> (LTC_MP_DIGIT_BIT - 1)) & 1);
       buf <<= 1;
 
       if (mode == 0 && i == 0) {
@@ -146,16 +140,12 @@ done:
        ltc_ecc_del_point(M[i]);
    }
 error:
-   if (ma != NULL) mp_clear(ma);
-   if (a_plus3 != NULL) mp_clear(a_plus3);
-   if (mu != NULL) mp_clear(mu);
-   if (mp != NULL) mp_montgomery_free(mp);
+   if (ma != NULL) ltc_mp_clear(ma);
+   if (a_plus3 != NULL) ltc_mp_clear(a_plus3);
+   if (mu != NULL) ltc_mp_clear(mu);
+   if (mp != NULL) ltc_mp_montgomery_free(mp);
    return err;
 }
 
 #endif
 #endif
-/* ref:         $Format:%D$ */
-/* git commit:  $Format:%H$ */
-/* commit time: $Format:%ai$ */
-
