@@ -17,7 +17,7 @@
 */
 int pkcs_1_os2ip(void *n, unsigned char *in, unsigned long inlen)
 {
-   return mp_read_unsigned_bin(n, in, inlen);
+   return ltc_mp_read_unsigned_bin(n, in, inlen);
 }
 
 #endif /* LTC_PKCS_1 */
